@@ -102,28 +102,29 @@ def get_colours(colour_specs):
             raise SkoolKitError("Invalid colour spec: {}={}".format(k, v))
     return colours
 
-def copy_resources(search_dir, root_dir, paths, files_param, path_param, theme=None, suffix=None):
-    fnames = paths.get(files_param)
+def copy_resources(search_dir, root_dir, fnames, dest, themes=None, suffix=None, indent=0):
     if fnames:
-        dest = paths.get(path_param, '')
         actual_files = []
         for fname in fnames.split(';'):
-            f = None
-            if theme and fname.endswith(suffix):
-                f = find('{0}-{1}{2}'.format(fname[:-len(suffix)], theme, suffix), search_dir)
-            if not f:
-                f = find(fname, search_dir)
+            files = []
+            f = find(fname, search_dir)
             if f:
+                files.append(f)
+            else:
+                raise SkoolKitError('{0}: file not found'.format(fname))
+            if themes and fname.endswith(suffix):
+                for theme in themes:
+                    f = find('{0}-{1}{2}'.format(fname[:-len(suffix)], theme, suffix), search_dir)
+                    if f:
+                        files.append(f)
+            for f in files:
                 base_f = basename(f)
                 actual_files.append(base_f)
                 html_f = posixpath.normpath(join(root_dir, dest, base_f))
                 if not isfile(html_f) or os.stat(f).st_mtime > os.stat(html_f).st_mtime:
-                    notify('Copying {0} to {1}'.format(f, html_f))
+                    notify('{}Copying {} to {}'.format(indent * ' ', f, html_f))
                     shutil.copy2(f, html_f)
-            else:
-                raise SkoolKitError('{0}: file not found'.format(fname))
-        if theme:
-            paths[files_param] = ';'.join(actual_files)
+        return ';'.join(actual_files)
 
 def get_prefix(fname):
     if '.' in fname:
@@ -216,11 +217,12 @@ def process_file(infile, topdir, files, case, base, pages, config_specs, new_ima
             raise SkoolKitError('Invalid page ID: {0}'.format(page_id))
     pages = pages or all_page_ids
 
-    write_disassembly(html_writer, html_writer_class, files, search_dir, pages, css_theme)
+    write_disassembly(html_writer, files, search_dir, pages, css_theme)
 
-def write_disassembly(html_writer, html_writer_class, files, search_dir, pages, css_theme):
+def write_disassembly(html_writer, files, search_dir, pages, css_theme):
     game_dir = html_writer.file_info.game_dir
     paths = html_writer.paths
+    game_vars = html_writer.game_vars
 
     # Create the disassembly subdirectory if necessary
     odir = html_writer.file_info.odir
@@ -228,14 +230,9 @@ def write_disassembly(html_writer, html_writer_class, files, search_dir, pages,
         notify('Creating directory {0}'.format(odir))
         os.makedirs(odir)
 
-    # Copy CSS, JavaScript and font files if necessary
-    copy_resources(search_dir, odir, paths, 'StyleSheet', 'StyleSheetPath', css_theme, '.css')
-    copy_resources(search_dir, odir, paths, 'JavaScript', 'JavaScriptPath')
-    copy_resources(search_dir, odir, paths, 'Font', 'FontPath')
-
-    # Write logo image file if necessary
-    if html_writer.write_logo_image(odir):
-        notify('  Wrote {0}'.format(join(game_dir, paths['Logo'])))
+    # Copy CSS and font files if necessary
+    html_writer.set_style_sheet(copy_resources(search_dir, odir, game_vars.get('StyleSheet'), paths.get('StyleSheetPath', ''), css_theme, '.css'))
+    copy_resources(search_dir, odir, game_vars.get('Font'), paths.get('FontPath', ''))
 
     # Write disassembly files
     if 'd' in files:
@@ -252,6 +249,8 @@ def write_disassembly(html_writer, html_writer_class, files, search_dir, pages,
     # Write pages defined in the ref file
     if 'P' in files:
         for page_id in pages:
+            page_details = html_writer.pages[page_id]
+            copy_resources(search_dir, odir, page_details.get('JavaScript'), paths.get('JavaScriptPath', ''), indent=2)
             clock(html_writer.write_page, '  Writing {0}'.format(join(game_dir, paths[page_id])), page_id)
 
     # Write other files
@@ -275,8 +274,8 @@ def write_disassembly(html_writer, html_writer_class, files, search_dir, pages,
         mode = html_writer.parser.mode
         for code_id, code in html_writer.other_code:
             skoolfile = find(code['Source'], search_dir)
-            skool2_parser = clock(SkoolParser, '  Parsing {0}'.format(skoolfile), skoolfile, case=html_writer.case, base=html_writer.base, html=True, create_labels=mode.create_labels, asm_labels=mode.asm_labels)
-            skool2_writer = html_writer_class(skool2_parser, html_writer.ref_parser, html_writer.file_info, html_writer.image_writer, html_writer.case, code_id)
+            skool2_parser = clock(html_writer.parser.clone, '  Parsing {0}'.format(skoolfile), skoolfile)
+            html_writer2 = html_writer.clone(skool2_parser, code_id)
             map_path = code['Index']
             asm_path = code['Path']
             map_details = {
@@ -284,8 +283,8 @@ def write_disassembly(html_writer, html_writer_class, files, search_dir, pages,
                 'AsmPath': asm_path,
                 'Title': code['Title']
             }
-            clock(skool2_writer.write_map, '    Writing {0}'.format(join(game_dir, map_path)), map_details)
-            clock(skool2_writer.write_entries, '    Writing disassembly files in {0}'.format(join(game_dir, asm_path)), asm_path, map_path, code['Header'])
+            clock(html_writer2.write_map, '    Writing {0}'.format(join(game_dir, map_path)), map_details)
+            clock(html_writer2.write_entries, '    Writing disassembly files in {0}'.format(join(game_dir, asm_path)), asm_path, map_path, code['Header'])
 
     # Write index.html
     if 'i' in files:
@@ -305,7 +304,7 @@ def run(files, options):
             os.makedirs(topdir)
 
     for infile in files:
-        process_file(infile, topdir, options.files, options.case, options.base, options.pages, options.config_specs, options.new_images, options.theme, options.create_labels, options.asm_labels)
+        process_file(infile, topdir, options.files, options.case, options.base, options.pages, options.config_specs, options.new_images, options.themes, options.create_labels, options.asm_labels)
 
 def main(args):
     global verbose, show_timings
@@ -347,8 +346,8 @@ def main(args):
                        help="Be quiet")
     group.add_argument('-t', '--time', dest='show_timings', action='store_true',
                        help="Show timings")
-    group.add_argument('-T', '--theme', dest='theme', metavar='THEME',
-                       help="Use this CSS theme")
+    group.add_argument('-T', '--theme', dest='themes', metavar='THEME', action='append',
+                       help="Use this CSS theme; this option may be used multiple\ntimes")
     group.add_argument('-u', '--upper', dest='case', action='store_const', const=CASE_UPPER,
                        help="Write the disassembly in upper case")
     group.add_argument('-V', '--version', action='version',
