@@ -109,7 +109,8 @@ class AsmWriter:
                     org_dir = 'org'
                 else:
                     org_dir = 'ORG'
-                self.write_line('{0}{1} {2}'.format(self.indent, org_dir, org))
+                org_addr_str = self.parser.convert_address_operand(org)
+                self.write_line('{0}{1} {2}'.format(self.indent, org_dir, org_addr_str))
                 self.write_line('')
             self.entry = entry
             self.print_entry()
@@ -297,21 +298,28 @@ class AsmWriter:
         end, params, p_text = parse_params(text, index, chars='@')
         if p_text:
             return end, p_text
-        addr_str = params[:5]
-        if params[5:].startswith('@'):
-            return end, addr_str
+        anchor_index = params.find('#')
+        if anchor_index > 0:
+            params = params[:anchor_index]
+        code_id = ''
+        code_id_index = params.find('@')
+        if code_id_index > 0:
+            code_id = params[code_id_index + 1:]
+            params = params[:code_id_index]
+        addr_str = params
         address = parse_int(addr_str)
+        if code_id:
+            return end, self.parser.get_instruction_addr_str(address, code_id)
         label = self.labels.get(address)
         if label is None:
             if self.base_address <= address <= self.end_address:
                 self.warn('Could not convert address {0} to label'.format(addr_str))
-            instructions = self.parser.instructions.get(address)
-            if instructions:
-                label = instructions[0].addr_str
-            elif addr_str.startswith('$'):
-                label = addr_str[1:]
-            else:
-                label = addr_str
+            label = self.parser.get_instruction_addr_str(address)
+            if label is None:
+                if addr_str.startswith('$'):
+                    label = addr_str[1:]
+                else:
+                    label = addr_str
         return end, label
 
     def expand_refs(self, text, index):
