@@ -140,7 +140,6 @@ class HtmlWriter:
             link_text[page_id] = page.get('Link', titles[page_id])
         links = self._parse_links(link_text)
 
-        self._img_path = None
         self.paths = self._get_paths()
         self.paths.update(paths)
         self.titles = self._get_titles()
@@ -173,6 +172,7 @@ class HtmlWriter:
         self.game = self.game_vars.get('Game', def_game_name)
         link_operands = self.game_vars.get('LinkOperands', 'CALL,DEFW,DJNZ,JP,JR')
         self.link_operands = tuple(op.upper() for op in link_operands.split(','))
+        self.game_vars.setdefault('StyleSheet', 'skoolkit.css')
 
         self.bugs = self.get_sections('Bug', True)
         self.facts = self.get_sections('Fact', True)
@@ -198,6 +198,14 @@ class HtmlWriter:
         """
         return
 
+    def clone(self, skool_parser, code_id):
+        the_clone = self.__class__(skool_parser, self.ref_parser, self.file_info, self.image_writer, self.case, code_id)
+        the_clone.set_style_sheet(self.game_vars['StyleSheet'])
+        return the_clone
+
+    def set_style_sheet(self, value):
+        self.game_vars['StyleSheet'] = value
+
     def _build_footer(self):
         lines = ['<div class="footer">']
         release_name = self.info.get('Release')
@@ -298,14 +306,6 @@ class HtmlWriter:
         """
         return self.parser.get_entry_point_refs(address)
 
-    def get_container(self, address):
-        """Return the routine or data block that contains `address`."""
-        return self.parser.get_container(address)
-
-    def get_instruction_addr_str(self, address):
-        """Return the address string of the instruction at `address`."""
-        return self.parser.instructions[address][0].addr_str
-
     def get_snapshot_name(self):
         """Return the name of the current memory snapshot."""
         return self._snapshots[-1][1]
@@ -337,8 +337,6 @@ class HtmlWriter:
             'ScreenshotImagePath': join(images_path, 'scr'),
             'StyleSheetPath': '.',
             'UDGImagePath': join(images_path, 'udgs'),
-            'Logo': join(images_path, 'logo.{0}'.format(self.default_image_format)),
-            'StyleSheet': 'skoolkit.css',
             P_GAME_INDEX: 'index.html',
             P_MEMORY_MAP: join(maps_path, 'all.html'),
             P_ROUTINES_MAP: join(maps_path, 'routines.html'),
@@ -977,7 +975,7 @@ class HtmlWriter:
         ofile, cwd = self.open_file(self.paths[page_id])
         page = self.pages[page_id]
         body_class = page.get('BodyClass')
-        js = page.get('JavaScript', '0') != '0'
+        js = page.get('JavaScript')
         self.write_header(ofile, self.titles[page_id], cwd, body_class, js=js)
         page_content = self.expand(self.page_contents[page_id], cwd).strip()
         ofile.write('{0}\n'.format(page_content))
@@ -988,24 +986,28 @@ class HtmlWriter:
         cwd = os.path.dirname(fname)
         return ofile, cwd
 
-    def write_head(self, ofile, title, cwd, js=False):
+    def write_head(self, ofile, title, cwd, js=None):
         ofile.write(PROLOGUE)
         ofile.write('<head>\n')
         ofile.write('<meta http-equiv="content-type" content="text/html; charset=utf-8" />\n')
         ofile.write('<title>{0}: {1}</title>\n'.format(self.game, title))
-        for css_file in self.paths['StyleSheet'].split(';'):
+        for css_file in self.game_vars['StyleSheet'].split(';'):
             ofile.write('<link rel="stylesheet" type="text/css" href="{0}" />\n'.format(FileInfo.relpath(cwd, join(self.paths['StyleSheetPath'], basename(css_file)))))
         if js:
-            for js_file in self.paths['JavaScript'].split(';'):
+            for js_file in js.split(';'):
                 ofile.write('<script type="text/javascript" src="{0}"></script>\n'.format(FileInfo.relpath(cwd, join(self.paths['JavaScriptPath'], basename(js_file)))))
         ofile.write('</head>\n')
 
     def _get_logo(self, cwd):
-        if self.file_exists(self.paths['Logo']):
-            return '<img src="{0}" alt="{1}" />'.format(FileInfo.relpath(cwd, self.paths['Logo']), self.game)
+        logo_macro = self.game_vars.get('Logo')
+        if logo_macro:
+            return self.expand(logo_macro, cwd)
+        logo_image = self.game_vars.get('LogoImage')
+        if logo_image and self.file_exists(logo_image):
+            return '<img src="{0}" alt="{1}" />'.format(FileInfo.relpath(cwd, logo_image), self.game)
         return self.game
 
-    def write_header(self, ofile, title, cwd, body_class, body_title=None, js=False):
+    def write_header(self, ofile, title, cwd, body_class, body_title=None, js=None):
         self.write_head(ofile, title, cwd, js)
         index = FileInfo.relpath(cwd, self.paths[P_GAME_INDEX])
         if body_class:
@@ -1019,14 +1021,6 @@ class HtmlWriter:
         ofile.write('</tr>\n')
         ofile.write('</table>\n')
 
-    def write_logo_image(self, cwd):
-        logo_macro = self.game_vars.get('Logo')
-        if logo_macro:
-            self.expand(logo_macro, cwd)
-            if self._img_path:
-                self.paths['Logo'] = self._img_path
-            return self._img_path
-
     def write_image(self, image_path, udgs, crop_rect=(), scale=2, mask=False):
         """Create an image and write it to a file.
 
@@ -1055,7 +1049,6 @@ class HtmlWriter:
             f = self.file_info.open_file(image_path, mode='wb')
             self.image_writer.write_image(udgs, f, img_format, scale, mask, *crop_rect)
             f.close()
-            self._img_path = image_path
 
     def _create_macros(self):
         self.macros = {}
@@ -1167,7 +1160,6 @@ class HtmlWriter:
         :param path_id: The ID of the target directory (as defined in the
                         :ref:`paths` section of the `ref` file).
         """
-        self._img_path = None
         if fname:
             if fname[-4:].lower() in ('.png', '.gif'):
                 suffix = ''
@@ -1392,21 +1384,24 @@ class HtmlWriter:
         if code_id_index > 0:
             code_id = params[code_id_index + 1:]
             params = params[:code_id_index]
+        if code_id:
+            code_path = self.get_code_path(code_id)
+            if code_path is None:
+                raise MacroParsingError("Could not find code path for '{}' disassembly".format(code_id))
+        else:
+            code_path = self.code_path
         addr_str = params
         address = parse_int(addr_str)
-        container = self.get_container(address)
+        container = self.parser.get_container(address, code_id)
         if not code_id and not container:
             raise MacroParsingError('Could not find routine file containing {0}'.format(addr_str))
-        if code_id:
-            inst_addr_str = addr_str
-            container_address = address
-            code_path = self.get_code_path(code_id)
-        else:
-            inst_addr_str = self.get_instruction_addr_str(address)
+        inst_addr_str = self.parser.get_instruction_addr_str(address, code_id)
+        if container:
             container_address = container.address
-            code_path = self.code_path
-            if address != container_address:
-                anchor = '#{0}'.format(address)
+        else:
+            container_address = address
+        if address != container_address:
+            anchor = '#{0}'.format(address)
         asm_label = self.parser.get_asm_label(address)
         ref_file = FileInfo.asm_relpath(cwd, container_address, code_path)
         link = '<a class="link" href="{0}{1}">{2}</a>'.format(ref_file, anchor, link_text or asm_label or inst_addr_str)
