@@ -222,12 +222,14 @@ class SkoolParser:
     def __init__(self, skoolfile, case=None, base=None, asm_mode=0, warnings=False, fix_mode=0, html=False, create_labels=False, asm_labels=True):
         self.skoolfile = skoolfile
         self.mode = Mode(case, base, asm_mode, warnings, fix_mode, html, create_labels, asm_labels)
+        self.case = case
         self.base = base
 
         self.snapshot = [0] * 65536  # 64K of Spectrum memory
         self.instructions = {}       # address -> [Instructions]
         self.entries = {}            # address -> Routine/Data
         self.memory_map = []         # Routines and Datas
+        self.base_address = 65536
         self.header = []
         self.stack = []
         self.comments = []
@@ -238,17 +240,32 @@ class SkoolParser:
         with open_file(skoolfile) as f:
             self._parse_skool(f)
 
+    def clone(self, skoolfile):
+        return SkoolParser(
+            skoolfile,
+            self.case,
+            self.base,
+            self.mode.asm_mode,
+            self.mode.warn,
+            self.mode.fix_mode,
+            self.mode.html,
+            self.mode.create_labels,
+            self.mode.asm_labels
+        )
+
     def get_entry(self, address):
         """Return the routine or data block that starts at `address`."""
         return self.entries.get(address)
 
-    def get_instruction(self, address):
+    def get_instruction(self, address, asm_id=''):
         """Return the instruction at `address`."""
-        return self.instructions.get(address, [None])[0]
+        for instruction in self.instructions.get(address, []):
+            if instruction.container.asm_id.lower() == asm_id.lower():
+                return instruction
 
-    def get_container(self, address):
+    def get_container(self, address, asm_id):
         """Return the routine or data block that contains `address`."""
-        instruction = self.get_instruction(address)
+        instruction = self.get_instruction(address, asm_id)
         if instruction:
             return instruction.container
 
@@ -263,6 +280,16 @@ class SkoolParser:
         if instruction:
             return instruction.asm_label
 
+    def get_instruction_addr_str(self, address, asm_id=''):
+        instruction = self.get_instruction(address, asm_id)
+        if instruction:
+            return instruction.addr_str
+        if asm_id:
+            return self.mode.get_addr_str(address)
+
+    def convert_address_operand(self, operand):
+        return self.mode.convert_address_operand(operand)
+
     def _parse_skool(self, skoolfile):
         map_entry = None
         instruction = None
@@ -312,6 +339,7 @@ class SkoolParser:
                 self.entries[address] = map_entry
                 self.memory_map.append(map_entry)
                 self.comments[:] = []
+                self.base_address = min((address, self.base_address))
             elif ctl == 'd':
                 # This is a data definition entry
                 map_entry = None
@@ -632,10 +660,10 @@ class SkoolParser:
                 # Warn if we cannot find a label to replace the operand of this
                 # routine instruction (will need @nowarn if this is OK)
                 self.warn('Found no label for operand: {0} {1}'.format(instruction.address, operation))
-        elif label_warn and self.mode.do_ssubs and operand_int > 23755:
-            # Warn if the operand is > 23755 (where code might be) but doesn't
-            # refer to the address of an instruction (will need @nowarn if this
-            # is OK)
+        elif label_warn and self.mode.do_ssubs and operand_int >= self.base_address:
+            # Warn if the operand is at or above the base address of the
+            # disassembly (where code might be) but doesn't refer to the
+            # address of an instruction (will need @nowarn if this is OK)
             self.warn('Unreplaced operand: {0} {1}'.format(instruction.address, operation))
 
 class Mode:
@@ -645,10 +673,12 @@ class Mode:
         self.decimal = base == BASE_10
         self.hexadecimal = base == BASE_16
         self.html = html
+        self.asm_mode = asm_mode
         self.asm = asm_mode > 0
         self.warn = warnings
         self.started = asm_mode == 0
         self.include = self.started
+        self.fix_mode = fix_mode
         self.do_rfixes = fix_mode >= 3
         self.do_rsubs = asm_mode >= 3 or self.do_rfixes
         self.do_ssubs = asm_mode >= 2
@@ -660,9 +690,13 @@ class Mode:
         self.ignoretua = False
         self.ignoredua = False
         if self.lower:
+            self.hex2fmt = '${0:02x}'
             self.hex4fmt = '${0:04x}'
+            self.addr_fmt = '{0:04x}'
         else:
+            self.hex2fmt = '${0:02X}'
             self.hex4fmt = '${0:04X}'
+            self.addr_fmt = '{0:04X}'
         self.reset()
 
     def reset(self):
@@ -720,6 +754,18 @@ class Mode:
 
         self.reset()
 
+    def get_addr_str(self, address):
+        if self.hexadecimal:
+            return self.addr_fmt.format(address)
+        return str(address)
+
+    def convert_address_operand(self, operand):
+        if self.decimal:
+            return str(parse_int(operand))
+        if self.hexadecimal:
+            return self.hex4fmt.format(parse_int(operand))
+        return operand
+
     def apply_case(self, addr_str, operation):
         if self.lower:
             addr_str = addr_str.lower()
@@ -847,13 +893,11 @@ class Mode:
         num = parse_int(num_str)
         if self.decimal:
             return text.replace(num_str, str(num))
-        elif self.hexadecimal:
+        if self.hexadecimal:
             if digits <= 2 and num < 256:
-                hex_fmt = '${0:02X}'
+                hex_fmt = self.hex2fmt
             else:
-                hex_fmt = '${0:04X}'
-            if self.lower:
-                hex_fmt = hex_fmt.lower()
+                hex_fmt = self.hex4fmt
             return text.replace(num_str, hex_fmt.format(num))
 
 class Instruction:
@@ -922,7 +966,7 @@ class Comment:
 
 class SkoolEntry:
     def __init__(self, address, addr_str=None, ctl=None, description=None, details=()):
-        self.asm_id = None
+        self.asm_id = ''
         self.address = address
         self.addr_str = addr_str
         self.ctl = ctl
